import os
import click
import pyttsx3


def female_speak(text):
    engine = pyttsx3.init()
    engine.setProperty("rate", 200)
    engine.setProperty("volume", 1)
    voices = engine.getProperty("voices")
    engine.setProperty("voice", voices[1].id)
    engine.say(text)
    engine.runAndWait()


class ComplexCLI(click.MultiCommand):
    def list_commands(self, ctx):
        commands = []
        commands_folder = os.path.join(os.path.dirname(__file__), "commands")
        for filename in os.listdir(commands_folder):
            if filename.endswith(".py") and filename.startswith("cmd_"):
                commands.append(filename.replace("cmd_", "").replace(".py", ""))
        commands.sort()
        return commands

    def get_command(self, ctx, name):
        try:
            mod = __import__(f"eve.commands.cmd_{name}", None, None, ["cli"])
        except ImportError:
            return
        return mod.cli


@click.command(cls=ComplexCLI)
def cli():
    """Hey! I am Eve, your command line assistant!"""
    pass



from pyowm import OWM
from eve.config import WX_API_KEY, WX_LOCATION, WX_METRIC_TEMP, WX_METRIC_WIND


class Weather:

    def __init__(self, api_key = None, metric_temp = None, metric_wind = None):
        self.manager = OWM(api_key or WX_API_KEY).weather_manager()
        self.default_location = WX_LOCATION
        self.metric_temp = metric_temp or WX_METRIC_TEMP
        self.metric_wind = metric_wind or WX_METRIC_WIND

    def get_weather_data(self, weather):
        return {
            "max": weather.temperature(self.metric_temp)["temp_max"],
            "min": weather.temperature(self.metric_temp)["temp_min"],
            "temp": weather.temperature(self.metric_temp)["temp"],
            "wind": weather.wind(self.metric_wind)['speed'],
            "status": weather.detailed_status,
            "sun_rise": weather.srise_time,
            "sun_set": weather.sset_time,
            "rain": weather.rain,
            "time": weather.ref_time,
        }

    def current(self, location = None):
        observation = self.manager.weather_at_place(location or self.default_location)
        weather = observation.weather

        result = self.get_weather_data(weather)
        result['location'] = f'{observation.location.name} {observation.location.country}'
        return result

    def forecast(self, location = None, weather=None, interval='3h'):
        forecaster = self.manager.forecast_at_place(location or self.default_location, interval)
        location = f"{forecaster.forecast.location.name} {forecaster.forecast.location.country}"

        return [
            {**self.get_weather_data(weather), **{'location' : location}} for weather in forecaster.forecast.weathers
        ]




import click
import subprocess
import re


@click.group()
def cli():
    """- Get Wi-Fi Passwords"""


@cli.command()
def show():
    command_output = subprocess.run(
        ["netsh", "wlan", "show", "profiles"], capture_output=True
    ).stdout.decode()
    profile_names = re.findall("All User Profile     : (.*)\r", command_output)
    wifi_list = []
    if len(profile_names) != 0:
        for name in profile_names:
            wifi_profile = {}
            profile_info = subprocess.run(
                ["netsh", "wlan", "show", "profile", name], capture_output=True
            ).stdout.decode()
            if re.search("Security key           : Absent", profile_info):
                continue
            else:
                wifi_profile["ssid"] = name
                profile_info_pass = subprocess.run(
                    ["netsh", "wlan", "show", "profile", name, "key=clear"],
                    capture_output=True,
                ).stdout.decode()
                password = re.search(
                    "Key Content            : (.*)\r", profile_info_pass
                )
                if password == None:
                    wifi_profile["password"] = None
                else:
                    wifi_profile["password"] = password[1]
                wifi_list.append(wifi_profile)

    for i in wifi_list:
        print(f"{i['ssid']} : {i['password']}")



import os
import collections
import click
from eve.config import TIDY_ROOT
import pyttsx3


def female_speak(text):
    engine = pyttsx3.init()
    engine.setProperty("rate", 200)
    engine.setProperty("volume", 1)
    voices = engine.getProperty("voices")
    engine.setProperty("voice", voices[1].id)
    engine.say(text)
    engine.runAndWait()


@click.command()
@click.option("-v", "--verbose", type=bool, help="Vebose Logging", default=False)
@click.option("-p", "--path", type=str, help="Directory to tidy", default=TIDY_ROOT)
def cli(verbose, path):
    """- Organizes your Downloads Folder"""
    root_dir = path or os.path.join(os.path.expanduser("~"), "Downloads")

    file_mappings = collections.defaultdict()

    for filename in os.listdir(root_dir):
        file_type = filename.split(".")[-1]
        file_mappings.setdefault(file_type, []).append(filename)

    click.echo("File Mappings created...")
    female_speak("File Mappings created...")

    for folder_name, folder_items in file_mappings.items():
        folder_path = os.path.join(root_dir, folder_name)
        if not os.path.exists(folder_path):
            os.mkdir(folder_path)

        if verbose:
            click.echo(
                f"Tidying {len(folder_items)} files in: {root_dir} ".center(100, "=")
            )
        for folder_item in folder_items:
            source = os.path.join(root_dir, folder_item)
            destination = os.path.join(folder_path, folder_item)
            try:
                click.echo(f"Moving {source} to {destination}... ")
                os.rename(source, destination)
            except PermissionError:
                pass
    click.echo("Tidying Downloads...")
    female_speak("Tidying Downloads...")
    click.echo("~~~~~~~~~~~~~~~~~~~~~~~~")
    click.echo("Downloads Tidied.")
    female_speak("Downloads Tidied.")



import click
import os
import json
from pprint import pprint


@click.group()
def cli():
    """- Password Manager"""

@cli.command()
@click.argument("masterpassword", type=str, required=True)
def show(masterpassword):
    '''- Show Passwords'''
    if masterpassword == os.environ.get('MASTER PASSWORD'):
        with open('D:/Varun/PROGRAMMING/Eve-CLI-Tool/eve/passwords.json', 'r') as passwds:
            raw_data = passwds.read()

        data = json.loads(raw_data)
        click.echo(f"These are your passwords...\n")
        for username in data.keys():
            click.echo(f"\t {username} : {data[username]} ")


@cli.command()
@click.argument("username", type=str, required=True)
@click.argument("password", type=str, required=True)
def add(username, password):
    '''- Add Password'''
    with open('D:/Varun/PROGRAMMING/Eve-CLI-Tool/eve/passwords.json', 'r') as passwds:
        raw_data = passwds.read()

    data = json.loads(raw_data)
    if username in data.keys():
        click.echo(f"key '{username}' already exists.")

    else:
        data[username] = password
        with open('D:/Varun/PROGRAMMING/Eve-CLI-Tool/eve/passwords.json', 'w') as passwds:
            json.dump(data, passwds, indent=4)


@cli.command()
@click.argument("username", type=str, required=True)
def remove(username):
    '''- Delete Password'''
    with open('D:/Varun/PROGRAMMING/Eve-CLI-Tool/eve/passwords.json', 'r') as passwds:
        raw_data = passwds.read()

    data = json.loads(raw_data)
    if username in data.keys():
        click.echo(f"'{username} : {data.pop(username)}' has been deleted.")
        with open('D:/Varun/PROGRAMMING/Eve-CLI-Tool/eve/passwords.json', 'w') as passwds:
            json.dump(data, passwds, indent=4)
    else:
        click.echo(f"key '{username}' does not exist.")



import os


# WX config
WX_API_KEY = "f9d9b5267c097ce0c06b9ee39ee35c80"
WX_LOCATION = "chennai"
WX_METRIC_TEMP = "celsius"
WX_METRIC_WIND = "miles_hour"


# TIDY DOWNLOADS CONFIG
TIDY_ROOT = None


# SEARCH ENGINE
google_url = "http://google.com/search?q="
wiki_url = "http://wikipedia.org/wiki/"
youtube_url = "https:/youtube.com/results?search_query="



import click


@click.command()
@click.argument("expression", type=str)
def cli(expression):
    '''- Evaluate an expression'''
    exp = True
    for i in expression:
        if i.isalpha():
            exp = False
            click.echo(f"Error : Cannot calculate this expression.\nEnter valid data type")
            break
        
    if exp:
        expression.replace("x", "*")
        expression.replace("^", "**")
        click.echo(f" {expression} = {eval(expression)} ")


import click
import webbrowser
from eve.config import google_url, wiki_url, youtube_url
import pyttsx3


def female_speak(text):
    engine = pyttsx3.init()
    engine.setProperty('rate',200)
    engine.setProperty('volume', 1)
    voices = engine.getProperty('voices')
    engine.setProperty('voice', voices[1].id)
    engine.say(text)
    engine.runAndWait()


class Context:
    def __init__(self, topic):
        self.topic = str(topic)

@click.group()
@click.option("-t", "--topic", type=str, help="Topic you want to search for", default=google_url)
@click.pass_context
def cli(ctx, topic):
    '''- Search For Something'''
    ctx.obj = Context(topic)


@cli.command()
@click.pass_context
def google(ctx):
    '''- Search in google'''
    topic_list = str(ctx.obj.topic).split()
    url = google_url
    for i in range(0, len(topic_list)):
        if i == len(topic_list) - 1:
            url += topic_list[i]
        else:
            url += topic_list[i] + "+"
    click.echo(f"Opening {str(ctx.obj.topic)} in google...")
    female_speak(f"Opening {str(ctx.obj.topic)} in google...")
    webbrowser.open(url)


@cli.command()
@click.pass_context
def wiki(ctx):
    '''- Search in wikipedia'''
    topic_list = str(ctx.obj.topic).split()
    url = wiki_url
    for i in range(0, len(topic_list)):
        if i == len(topic_list) - 1:
            url += topic_list[i]
        else:
            url += topic_list[i] + "_"
    click.echo(f"Opening {str(ctx.obj.topic)} in wikipedia...")
    female_speak(f"Opening {str(ctx.obj.topic)} in wikipedia...")
    webbrowser.open(url)


@cli.command()
@click.pass_context
def yt(ctx):
    '''- Search in youtube'''
    topic_list = str(ctx.obj.topic).split()
    url = youtube_url
    for i in range(0, len(topic_list)):
        if i == len(topic_list) - 1:
            url += topic_list[i]
        else:
            url += topic_list[i] + "+"
    click.echo(f"Opening {str(ctx.obj.topic)} in youtube...")
    female_speak(f"Opening {str(ctx.obj.topic)} in youtube...")
    webbrowser.open(url)


import click
from eve.service import svc_weather
import time
import pyttsx3


def female_speak(text):
    engine = pyttsx3.init()
    engine.setProperty('rate',200)
    engine.setProperty('volume', 1)
    voices = engine.getProperty('voices')
    engine.setProperty('voice', voices[1].id)
    engine.say(text)
    engine.runAndWait()

def convert_epoch_to(epoch, fmt):
    return time.strftime(fmt, time.localtime(epoch))

def is_around_midday(epoch):
    return 11 <= int(convert_epoch_to(epoch, '%H')) <= 13


class Context:
    def __init__(self, location):
        self.location = location
        self.weather = svc_weather.Weather()


@click.group()
@click.option("-l", "--location", type=str, help="Weather at this location")
@click.pass_context
def cli(ctx, location):
    '''- Weather info'''
    ctx.obj = Context(location)

@cli.command()
@click.pass_context
def current(ctx):
    """Current weather info"""
    result = ctx.obj.weather.current(location=ctx.obj.location)
    click.echo(f" {result['location']} - {result['status'].upper()} ".center(45, "="))
    female_speak(f" Bringning to you the current weather in {result['location']}...")
    female_speak(f"The weather is {result['status'].upper()} ")
    click.echo(f"\U0001F525 Temp: {result['temp']} - {result['min']}/{result['max']} (min/max) ")
    female_speak(f" The temperature is {int(result['temp'])} degrees celsius")
    female_speak(f"The minimum temperature is {int(result['min'])} degrees celsius and the maximum temperature is {int(result['max'])} degrees celsius")
    click.echo(f"\U0001F32A Wind: {round(result['wind'], 1)}")
    female_speak(f" Wind speeds are at {round(result['wind'], 1)} miles per hour")
    click.echo(f"\U0001F4A7 Rain: {result['rain']}")
    if result['rain'] == {}:
        pass
    else:
        female_speak(f" Rainfall status is {result['rain']}")
    click.echo(
        f"\U0001F315 Sunrise: {time.strftime('%H:%m %p', time.localtime(result['sun_rise']))} \n"
        f"\U0001F311 Sun set: {time.strftime('%H:%m %p', time.localtime(result['sun_set']))} "
    )


@cli.command()
@click.pass_context
def forecast(ctx):
    """Weather forecast for the week"""

    def formatter(data):
        if isinstance(data, float):
            data = round(data, 2)
        return str(data).center(14)

    to_display = [wx for wx in ctx.obj.weather.forecast(location=ctx.obj.location) if is_around_midday(wx['time'])]
    click.echo(f" {to_display[0]['location']} ".center(int(14*5.5), "="))
    female_speak(f" Bringin weather forecast in {to_display[0]['location']} ")
    click.echo("\U0001F4C5 Date:" + "".join([formatter(convert_epoch_to(wx['time'], "%a %d %b")) for wx in to_display]))
    click.echo("\U0001F525 Temp:" + "".join([formatter(wx['temp']) for wx in to_display]))
    click.echo("\U0001F32A Rain:" + "".join([formatter(wx['wind']) for wx in to_display]))
    click.echo("\U0001F4A7 Wind:" + "".join([formatter(wx['rain']) for wx in to_display]))
    
    # female_speak("Date:" + "".join([formatter(convert_epoch_to(wx['time'], "%a %d %b")) for wx in to_display]))
    # female_speak("Temp:" + "".join([formatter(wx['temp']) for wx in to_display]))
    # female_speak("Rain:" + "".join([formatter(wx['wind']) for wx in to_display]))
    # female_speak("Wind:" + "".join([formatter(wx['rain']) for wx in to_display]))



from setuptools import setup, find_packages


def read_requirements():
    with open("requirements.txt") as req:
        content = req.read()
        requirements = content.split("\n")
    return requirements


setup(
    name="EVE-CLI-ASSISTANT",
    version="0.1",
    author="Varun Suresh",
    description="EVE is a cli tool.",
    long_description="This is EVE, a command line based tool to help automate some processes and speeden up things.",
    url="https://github.com/VaryV/EVE-CLI-ASSISTANT",
    keywords=[
        "eve",
        "cli tool",
        "python cli tool",
        "eve cli tool",
        "eve command line tool",
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=read_requirements(),
    entry_points="""
        [console_scripts]
        eve = eve.cli:cli
    """,
)



import click
import tkinter
from tkinter import colorchooser


@click.command()
@click.option("-cf", "--colorformat", default=None)
def cli(colorformat):
    '''- Pick a color in HEX or RGB format'''
    color_picked = colorchooser.askcolor()
    if colorformat == None:
        click.echo(f"You have selected:\n\tHEX COLOR CODE : {color_picked[1]}\n\tRGB COLOR CODE : {color_picked[0]}")
    elif colorformat == "hex":
        click.echo(f"\n\tHEX COLOR CODE : {color_picked[1]}\n\t")
    elif colorformat == "rgb":
        click.echo(f"\n\tRGB COLOR CODE : {color_picked[0]}\n\t")
